<?php
ini_set('memory_limit', '-1');
class ListacitasC extends CI_Controller
{
	
	function __construct()
	{
		parent::__construct();
		
		$this->load->model('agenda/cosmetologo/agendaC_model');
		$this->load->library(array('session','form_validation'));
	}

	public function index(){
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '2')
		{
			redirect(base_url().'acceso/acceso');
		} else {

     		$data['Franquicias']=$this->agendaC_model->BuscarFranquicia(); 
		 	 foreach ($data['Franquicias'] as $i => $Franquicias) 
			$this->db->select('*');
			$this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
			$this->db->where('Franquicias_IdFranquicias',$i);
			$data['consulta']=$this->db->get('agenda')->result();

		$this->load->view('layout/headerCos');
		$this->load->view('layout/menuCosmetologo');
		$data['cabinas']=$this->cabinas();
		$data['ReCabina']=$this->agendaC_model->BuscarCabina(); 
		$data['ReCategoria']=$this->agendaC_model->BuscarCategoria();
		$data['ReEstatusCita']=$this->agendaC_model->BuscarEstatusCita();
		$data['ReUsuario']=$this->agendaC_model->BuscarUsuario();
		$this->load->view('agenda/cosmetologo/agendaC_view',$data);
		$this->load->view('layout/footer');


	}}
	public function cabinas()
	{
		$cabinasExistentes=$this->agendaC_model->BuscarCabina();
		$i=0;
		foreach($cabinasExistentes as $i => $cabina)
		{
			$colores[$i]['id'] = $i;
			$colores[$i]['nombre'] = $cabina;
			switch($cabina)
			{
				case 'FACIAL':
					$colores[$i]['color'] = 'facial';
					break;
				case 'FACIAL 2':
					$colores[$i]['color'] = 'facial-2';
					break;
				case 'CORPORAL':
					$colores[$i]['color'] = 'corporal';
					break;
				case 'CORPORAL 2':
					$colores[$i]['color'] = 'corporal-2';
					break;
				case 'RELAJANTES/MASAJES':
					$colores[$i]['color'] = 'relajantes-masajes';
					break;
				case 'CAVITACION':
					$colores[$i]['color'] = 'cavitacion';
					break;
				case 'IPL/E-LIGHT':
					$colores[$i]['color'] = 'ipl-e-light';
					break;
				case 'PESTAÑAS':
					$colores[$i]['color'] = 'pestañas';
					break;
				case 'SAUNA':
					$colores[$i]['color'] = 'sauna';
					break;
				case 'SAUNA 2':
					$colores[$i]['color'] = 'sauna-2';
					break;
				case 'ADICIONAL':
					$colores[$i]['color'] = 'adicional';
					break;
				case 'CAPSULA INFRAROJA':
					$colores[$i]['color'] = 'capsula-infraroja';
					break;
				case 'UÑAS 1':
					$colores[$i]['color'] = 'uñas-1';
					break;
				case 'UÑAS 2':
					$colores[$i]['color'] = 'uñas-2';
					break;
				case 'UÑAS 3':
					$colores[$i]['color'] = 'uñas-3';
					break;
				default;
				$colores[$i]['color'] = 'blanco';
				break;
			}
			
			$i++;
			
		}
		
		return ($colores);
	}
	public function service(){
		$codigo = $this->input->post('codeService');
		/*echo  json_encode("codigo service".$codigo);*/
		$this->agendaC_model->BuscarServiciosNombre($codigo);
	}
	public function loadNamePromo(){
		$codigo = $this->input->post('codePromo');
		/*echo  json_encode("codigo service".$codigo);*/
		$this->agendaC_model->BuscarPromocionesNombre($codigo);
	}

	public function buscarporcabina(){ 
		$query2 = $this->input->get('query', TRUE);
		$r = $this->agendaC_model->buscarporcabina($query2);
		echo json_encode($r);
	}

	public function updEvento2(){
		$data['idCabina'] =  $this->input->post('idCabinaA');
		$data['nombreCliente'] =  $this->input->post('nombreClienteA');
		$data['idCategoria'] =  $this->input->post('idCategoriaA');
		$data['codePromo'] =  $this->input->post('codePromoA');
		$data['codeService'] =  $this->input->post('codeServiceA');
		$data['fechaAgendada'] =  $this->input->post('fechaAgendadaA');
		$data['horaInicio'] =  $this->input->post('hourStart');
		$data['horaFin'] =  $this->input->post('hourEnd');
		$data['estado'] =  $this->input->post('status') ;
		$data['descripcion'] =  $this->input->post('script');
		$data['idUserChange'] =  $this->input->post('user');
		$data['idEvento'] =  $this->input->post('idEventoA');


		$request = $this->agendaC_model->updEvento2($data);
		echo json_encode($request);
	}

	public function getEventos(){
		$r = $this->agendaC_model->getEventos();
		$coloresCabina= array(
		            "FACIAL"  =>  '#37579D',
		            "FACIAL 2"  =>  '#D8907C',
		            "CORPORAL"  =>  '#C0473E',
		            "CORPORAL 2"  =>  '#BE304A',
		            "RELAJANTES/MASAJES"  =>  '#47A3A0',
		            "CAVITACION"  =>  '#DFA130',
		            "IPL/E-LIGHT"  =>  '#76B9E5',
		            "PESTAÑAS"  =>  '#1E7999',
		            "SAUNA"  =>  '#EAC595',
		            "SAUNA 2" =>  '#4C418E',
		            "ADICIONAL" =>  '#902456',
		            "CAPSULA INFRAROJA" =>  '#BD2367',
		            "UÑAS 1" =>  '#A71929',
		            "UÑAS 2" =>  '#7890C4',
		            "UÑAS 3" =>  '#9DAB2D',

		        );
		
		foreach ($r as $item) 
		{ 
		        $datosProcesados[] = array(
		            "start"      =>  $item->start."T". $item->hoi,
		            "end"        =>  $item->start."T". $item->hof,
		            "id"         =>  $item->id,
		            "title" 	 =>  $item->clientes,
		            "cabina"     =>  $item->cabina,
		            "clientes"   =>  $item->clientes,
		            "categoria"  =>  $item->categoria,
		            "promociones"=>  $item->promociones,
		            "servicio"   =>  $item->servicio,
		            "hoi"      =>  $item->hoi,
		            "hof"      =>  $item->hof,
		            "est"      =>  $item->est,
		            "obs"      =>  $item->obs,
		            "usu"      =>  $item->usu,
		            "fecha"    =>  $item->fecha,
		            "nombreCabina"    =>  $item->NombreCabina,
		            "color"    =>  $coloresCabina[(String)$item->NombreCabina]

		        );
		}


		echo json_encode($datosProcesados);
		/*echo json_encode($r);*/
	}

	public function getEventos1(){
		$r = $this->agendaC_model->getEventos();
		echo json_encode($r);
	}

	// public function updEvento(){
	// 	$param['IdAgenda'] = $this->input->post('IdAgenda');
	// 	$param['Fecha'] = $this->input->post('Fecha');
	// 	//$param['fecfin'] = $this->input->post('fecfin');

	// 	$r = $this->agendaC_model->updEvento($param);

	// 	echo $r;
	// }

	// public function deleteEvento(){

	// 	$id = $this->input->post('IdAgenda');
	// 	$r = $this->agendaC_model->deleteEvento($id);
	// 	echo $r;
	// }
	public function enviaDatos(){
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '2')
		{
			redirect(base_url().'acceso/acceso');
		} else {
		$id= $this->uri->segment(5);
		$result = $this->agendaC_model->BuscaCliente($id);
		if(count($result)>0){
				foreach ($result as $row){
				$IdClientes = $row->IdClientes;
				$NombreCliente=$row->NombreCliente;
				} 
					$datos = array(
						'IdClientes' => $IdClientes,
						'NombreCliente' => $NombreCliente,
					);
				}
				else{}
				
		$this->load->view('layout/headerCos');
		$this->load->view('layout/menuCosmetologo');
		$datos['ReCabina']=$this->agendaC_model->BuscarCabina();
	    $datos['ReFranquicia']=$this->agendaC_model->BuscarFranquicia();
	    $datos['ReUsuario']=$this->agendaC_model->BuscarUsuario();
	    $datos['ReCategoria']=$this->agendaC_model->BuscarCategoria();
		// // $datos['ReCliente']=$this->agendaC_model->BuscarCliente();
		// $datos['ReServicios']=$this->agendaC_model->BuscarServicios();
		// $datos['RePromocionesInstitucionales']=$this->agendaC_model->BuscarPromocionesinstitucionales();
		// $datos['RePromocionesLocales']=$this->agendaC_model->BuscarPromocionesLocales();
		 $datos['ReEstatusCita']=$this->agendaC_model->BuscarEstatusCita();
		$this->load->view('agenda/cosmetologo/agregarcitaC_view', $datos);
		$this->load->view('layout/footer');
	 }

	}




	public function agregar(){
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '2')
		{
			redirect(base_url().'acceso/acceso');
		} else {
		$this->load->view('layout/headerCos');
		$this->load->view('layout/menuCosmetologo');
		$datos['ReCabina']=$this->agendaC_model->BuscarCabina();
	    $datos['ReFranquicia']=$this->agendaC_model->BuscarFranquicia();
	    $datos['ReUsuario']=$this->agendaC_model->BuscarUsuario();
	    $datos['ReCategoria']=$this->agendaC_model->BuscarCategoria();
		// // $datos['ReCliente']=$this->agendaC_model->BuscarCliente();
		// $datos['ReServicios']=$this->agendaC_model->BuscarServicios();
		// $datos['RePromocionesInstitucionales']=$this->agendaC_model->BuscarPromocionesinstitucionales();
		// $datos['RePromocionesLocales']=$this->agendaC_model->BuscarPromocionesLocales();
		 $datos['ReEstatusCita']=$this->agendaC_model->BuscarEstatusCita();
		$this->load->view('agenda/cosmetologo/agregarcitaC_view', $datos);
		$this->load->view('layout/footer');

	
	}
}
 //Esta funcion se uiliza para la vista agenda agregarCita_view
	public function guardar(){

	if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '2')
		{
			redirect(base_url().'acceso/acceso');
		} else {
			$data['Franquicias']=$this->agendaC_model->BuscarFranquicia(); 
			foreach ($data['Franquicias'] as $i => $Franquicias) 

		$parametro['Clientes_IdClientes']= $this->input->post('idcliente');
		$parametro['Categoria_IdCategoria']= '7';
		$parametro['ServiciosFranquicias_IdServiciosFranquicias']= $this->input->post('idservi');
		//$parametro['ServiciosFranquicias_IdServiciosFranquicias']= $this->input->post('idserviGM');
		$parametro['Promociones_IdPromociones']= $this->input->post('idpromo');
	   // $parametro['Promociones_IdPromociones']= $this->input->post('idpromoInst');
		$parametro['Fecha']= $this->input->post('txtfecha');
		$parametro['HoraInicio']= $this->input->post('txthorai');
		$parametro['HoraFin']= $this->input->post('txthoraf');
		$parametro['Cabina_IdCabina']= $this->input->post('txt_cabina');
		$parametro['estatuscitas_IdEstatusCita']= $this->input->post('txtstatus');
		$parametro['Observaciones']= $this->input->post('txt_observaciones');
		$parametro['Franquicias_IdFranquicias']= $i;
		$parametro['Usuarios_IdUsuarios']= $this->input->post('txtusuario');
	


		$this->agendaC_model->guardar($parametro);

		redirect('agenda/cosmetologo/listacitasC', 'refresh');
		}
	}


	public function buscarporfranquicia (){ 
	if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '2')
		{
			redirect(base_url().'acceso/acceso');
		} else {
		$this->db->select('*');
	$this->db->join('franquicias','Franquicias_IdFranquicias = IdFranquicias','inner');
		$data = array();
		$query = $this->input->get('query', TRUE);
		if ($query) {
			$result = $this->agendaC_model->buscarporfranquicia(trim($query));
			
			if ($result != FALSE){
				$data = array(
					'result' => $result,
					
);
			}else  {
				$data = array('result' => '');
			}	
		}else{
			$data = array('result' => '');
		}

		$this->load->view('layout/headerCos');
		$this->load->view('layout/menuCosmetologo');
		$data['ReFranq']=$this->agendaC_model->BuscarFranq();
		$this->load->view('agenda/cosmetologo/buscarAgendaC_view', $data);
		$this->load->view('layout/footer');
	}
}


}